# -*- coding: utf-8 -*-

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

from django.contrib.contenttypes.models import ContentType

from django.db import models
from django.contrib.auth.models import User


class Application(models.Model):
    name = models.CharField(max_length=60, unique=True, verbose_name="nome")
    python_name = models.CharField(max_length=255, unique=True, verbose_name="Nome no Python")
    managers = models.ManyToManyField(User, verbose_name='gestores', related_name='managed_applications')
    enabled = models.BooleanField(default=True, verbose_name="ativa")

    def __unicode__(self):
        return self.name

    url_name = 'aplicacao'

    class Meta(object):
        verbose_name = 'aplicação'
        verbose_name_plural = 'aplicações'


class Profile(models.Model):
    id = models.AutoField(primary_key=True)
    application = models.ForeignKey(Application, verbose_name='aplicação')
    name = models.CharField(max_length=60, verbose_name='nome')
    description = models.TextField(verbose_name='descrição')
    users = models.ManyToManyField(User, verbose_name='usuários', blank=True)

    def __unicode__(self):
        return self.name

    class Meta(object):
        verbose_name = 'perfil'
        verbose_name_plural = 'perfis'
        unique_together = (('application', 'name'),)


class DocumentTemplate(models.Model):
    name = models.CharField(max_length=60, verbose_name='nome')
    model = models.ForeignKey(ContentType)
    template = models.FileField(upload_to='rapid/document_templates')

    def __unicode__(self):
        return self.name

    class Meta(object):
        verbose_name = 'template de documento'
        verbose_name_plural = 'templates de documento'
